"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataSourceConfigProvider = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const services_1 = require("../services");
/**
 * A default implementation using SSM as the config provider is used
 * Can be overriden by implementing a provider for DataSourceConfigProviderFn
 * and binding it to DynamicDataSourceBinding.DATA_SOURCE_CONFIG_PROVIDER key
 */
let DataSourceConfigProvider = class DataSourceConfigProvider {
    constructor(awsSsmHelper) {
        this.awsSsmHelper = awsSsmHelper;
    }
    value() {
        return async (tenantId) => {
            const ssmKeyParamName = process.env.SSM_PREFIX
                ? `${process.env.SSM_PREFIX}/${tenantId}`
                : `${tenantId}`;
            const data = await this.awsSsmHelper.getSSMParameterValue(ssmKeyParamName);
            if (data === null || data === void 0 ? void 0 : data.Parameter) {
                const parameterStr = data.Parameter.Value
                    ? data.Parameter.Value.replace(/\n/gm, '')
                    : '';
                return [JSON.parse(parameterStr)];
            }
            return [];
        };
    }
};
exports.DataSourceConfigProvider = DataSourceConfigProvider;
exports.DataSourceConfigProvider = DataSourceConfigProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.service)(services_1.AwsSsmHelperService)),
    tslib_1.__metadata("design:paramtypes", [services_1.AwsSsmHelperService])
], DataSourceConfigProvider);
//# sourceMappingURL=datasource-config.provider.js.map