"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatasourceProvider = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const keys_1 = require("../keys");
/**
 * this provider returns a property with an async function,
 * this function returns a juggler datasource based on the config value
 * the property name will be the one used in the repository for datasource injection
 */
let DatasourceProvider = class DatasourceProvider {
    constructor(configProvider, config) {
        this.configProvider = configProvider;
        this.config = config;
    }
    value() {
        return async (datasourceIdentifier) => {
            var _a;
            const tenantId = datasourceIdentifier.id;
            if (!tenantId) {
                throw new rest_1.HttpErrors.InternalServerError('Tenant Id not available');
            }
            const dataSourceConfigs = await this.configProvider(tenantId);
            const dataSourceNames = (_a = this.config.dataSourceNames) !== null && _a !== void 0 ? _a : ['db'];
            return this.combineArraysIntoObject(dataSourceNames, dataSourceConfigs).then((combinedObject) => combinedObject);
        };
    }
    async combineArraysIntoObject(keys, configs) {
        // Map each config to an async function that creates a new instance of juggler.Datasource
        const asyncFunctions = configs.map(async (config) => {
            const dataSource = await this.createDatasource(config);
            return () => Promise.resolve(dataSource);
        });
        // Combine keys and resolved datasources into an object
        const combinedObject = {};
        keys.forEach((key, index) => {
            combinedObject[key] = async () => {
                const func = await asyncFunctions[index]; // Calling the async function here to resolve the promise
                return func();
            };
        });
        return combinedObject;
    }
    async createDatasource(config) {
        return new repository_1.juggler.DataSource(config);
    }
};
exports.DatasourceProvider = DatasourceProvider;
exports.DatasourceProvider = DatasourceProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(keys_1.DynamicDataSourceBinding.DATA_SOURCE_CONFIG_PROVIDER)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.DynamicDataSourceBinding.CONFIG)),
    tslib_1.__metadata("design:paramtypes", [Function, Object])
], DatasourceProvider);
//# sourceMappingURL=datasource.provider.js.map