"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProxyBuilderComponent = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const service_proxy_1 = require("@loopback/service-proxy");
const debug_1 = tslib_1.__importDefault(require("debug"));
const constants_1 = require("../../constants");
const constants_2 = require("./constants");
const keys_1 = require("./keys");
const services_1 = require("./services");
const types_1 = require("./types");
const debug = (0, debug_1.default)('loopback:proxy-builder:component');
let ProxyBuilderComponent = class ProxyBuilderComponent {
    constructor(application, options) {
        this.application = application;
        this.options = options;
        this.bindings = [
            (0, core_1.createBindingFromClass)(services_1.RestServiceModifier, {
                key: keys_1.ProxyBuilderBindings.PROXY_MODIFIER,
            }),
            (0, core_1.createBindingFromClass)(services_1.BelongsToRestResolver),
            (0, core_1.createBindingFromClass)(services_1.HasManyRestResolver),
            (0, core_1.createBindingFromClass)(services_1.HasOneRestResolver),
            core_1.Binding.bind(keys_1.ProxyBuilderBindings.TOKEN_VALIDATOR).to((context, token) => {
                if (!token && !context.token) {
                    throw new rest_1.HttpErrors.Unauthorized('No token provided');
                }
                return token !== null && token !== void 0 ? token : context.token;
            }),
        ];
        if (options.length) {
            options.forEach(config => {
                config.configs.forEach(modelConfig => {
                    var _a;
                    const processConfig = this._handleConfig(modelConfig);
                    const basePath = this._createBasePath(processConfig.model);
                    this._bindDataSource(processConfig.model, (_a = processConfig.basePath) !== null && _a !== void 0 ? _a : basePath, processConfig.restOperations, config.baseUrl);
                    this._bindService(processConfig.model, processConfig.relations);
                });
            });
        }
    }
    _handleConfig(config) {
        if ((0, types_1.isEntityRestConfig)(config)) {
            return config;
        }
        else {
            return {
                model: config,
            };
        }
    }
    _bindDataSource(model, basePath, restOperations, baseUrl) {
        if (baseUrl === undefined) {
            throw new Error('Base url is required');
        }
        this.application.bind(`datasources.${model.name}ProxyDataSource`).to(new repository_1.juggler.DataSource({
            name: `${model.name}Proxy`,
            connector: 'rest',
            baseURL: '',
            crud: false,
            options: {
                baseUrl: baseUrl,
                headers: {
                    accept: constants_1.CONTENT_TYPE.JSON,
                    ['content-type']: constants_1.CONTENT_TYPE.JSON,
                },
            },
            operations: [...(0, constants_2.restProxyBuilder)(basePath), ...(restOperations !== null && restOperations !== void 0 ? restOperations : [])],
        }));
        debug(`Bound datasource for ${model.name} on key - datasources.${model.name}ProxyDataSource`);
    }
    _bindService(model, restRelations) {
        class TempClass {
            async value() {
                const service = await (0, service_proxy_1.getService)(this.dataSource);
                return this.serviceModifier(service, model, restRelations !== null && restRelations !== void 0 ? restRelations : []);
            }
        }
        (0, core_1.inject)(`datasources.${model.name}ProxyDataSource`)(TempClass.prototype, 'dataSource');
        (0, core_1.inject)(keys_1.ProxyBuilderBindings.PROXY_MODIFIER)(TempClass.prototype, 'serviceModifier');
        this.application.bind(`services.${model.name}Proxy`).toProvider(TempClass);
        debug(`Bound service for ${model.name} on key - services.${model.name}Proxy`);
    }
    _createBasePath(model) {
        var _a, _b, _c;
        const basePath = (_b = (_a = model.definition.settings) === null || _a === void 0 ? void 0 : _a.rest) === null || _b === void 0 ? void 0 : _b.basePath;
        if (basePath) {
            return basePath;
        }
        return `/${(_c = model.modelName) === null || _c === void 0 ? void 0 : _c.toLowerCase()}`;
    }
};
exports.ProxyBuilderComponent = ProxyBuilderComponent;
exports.ProxyBuilderComponent = ProxyBuilderComponent = tslib_1.__decorate([
    (0, core_1.injectable)(),
    tslib_1.__param(0, (0, core_1.inject)(core_1.CoreBindings.APPLICATION_INSTANCE)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.ProxyBuilderBindings.CONFIG)),
    tslib_1.__metadata("design:paramtypes", [core_1.Application, Array])
], ProxyBuilderComponent);
//# sourceMappingURL=component.js.map