"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.asRestResolver = exports.restProxyBuilder = void 0;
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const constants_1 = require("../../constants");
const keys_1 = require("./keys");
function restProxyBuilder(basePath) {
    return [
        {
            template: {
                method: 'POST',
                url: basePath,
                headers: {
                    'content-type': constants_1.CONTENT_TYPE.JSON,
                    Authorization: '{token}',
                },
                body: '{body}',
            },
            functions: {
                create: ['token', 'body'],
            },
        },
        {
            template: {
                method: 'GET',
                url: `${basePath}/{id}`,
                headers: {
                    'content-type': constants_1.CONTENT_TYPE.JSON,
                    Authorization: '{token}',
                },
                query: {
                    filter: '{filter}',
                },
            },
            functions: {
                findById: ['token', 'id', 'filter'],
            },
        },
        {
            template: {
                method: 'GET',
                url: basePath,
                headers: {
                    'content-type': constants_1.CONTENT_TYPE.JSON,
                    Authorization: '{token}',
                },
                query: {
                    filter: '{filter}',
                },
            },
            functions: {
                find: ['token', 'filter'],
            },
        },
        {
            template: {
                method: 'PATCH',
                url: `${basePath}/{id}`,
                headers: {
                    'content-type': constants_1.CONTENT_TYPE.JSON,
                    Authorization: '{token}',
                },
                body: '{body}',
            },
            functions: {
                updateById: ['token', 'id', 'body'],
            },
        },
        {
            template: {
                method: 'DELETE',
                url: `${basePath}/{id}`,
                headers: {
                    'content-type': constants_1.CONTENT_TYPE.JSON,
                    Authorization: '{token}',
                },
            },
            functions: {
                deleteById: ['token', 'id'],
            },
        },
        {
            template: {
                method: 'GET',
                url: `${basePath}/count`,
                headers: {
                    'content-type': constants_1.CONTENT_TYPE.JSON,
                    Authorization: '{token}',
                },
                query: {
                    where: '{where}',
                },
            },
            functions: {
                count: ['token', 'where'],
            },
        },
        {
            template: {
                method: 'PUT',
                url: `${basePath}/{id}`,
                headers: {
                    'content-type': constants_1.CONTENT_TYPE.JSON,
                    Authorization: '{token}',
                },
                body: '{body}',
            },
            functions: {
                replaceById: ['token', 'id', 'body'],
            },
        },
        {
            template: {
                method: 'PATCH',
                url: basePath,
                headers: {
                    'content-type': constants_1.CONTENT_TYPE.JSON,
                    Authorization: '{token}',
                },
                body: '{body}',
                query: {
                    where: '{where}',
                },
            },
            functions: {
                update: ['token', 'body', 'where'],
            },
        },
        {
            template: {
                method: 'DELETE',
                url: basePath,
                headers: {
                    Authorization: '{token}',
                },
                query: {
                    where: '{where}',
                },
            },
            functions: {
                delete: ['token', 'where'],
            },
        },
    ];
}
exports.restProxyBuilder = restProxyBuilder;
const asRestResolver = () => (0, core_1.injectable)(binding => {
    (0, core_1.extensionFor)(keys_1.ServiceBuilderExtensionPoint.key)(binding);
    binding.tag({ namespace: keys_1.ServiceBuilderExtensionPoint.key });
});
exports.asRestResolver = asRestResolver;
//# sourceMappingURL=constants.js.map