/// <reference types="qs" />
/// <reference types="express" />
/// <reference types="cookie-parser" />
import { Getter, Provider } from '@loopback/core';
import { DataObject, Entity, Filter, FilterExcludingWhere, Where } from '@loopback/repository';
import { Request } from '@loopback/rest';
import { CrudRestService, CrudRestServiceModifier, IRestResolver, ModelConstructor, RestRelationConfig } from '../services';
export declare class RestServiceModifier<T extends Entity, S extends Entity> implements Provider<CrudRestServiceModifier<T>> {
    private resolverGetter;
    private _validateToken;
    private req?;
    private token;
    private resolvers;
    constructor(resolverGetter: Getter<IRestResolver<T, S>[]>, _validateToken: (context: RestServiceModifier<T, S>, token?: string) => string, req?: Request<import("express-serve-static-core").ParamsDictionary, any, any, import("qs").ParsedQs, Record<string, any>> | undefined);
    value(): Promise<(service: CrudRestService<T>, model: ModelConstructor<T>, config: RestRelationConfig[]) => {
        create: (data: DataObject<T>, token?: string | undefined) => Promise<T>;
        findById: (id: string, filter?: FilterExcludingWhere<T> | undefined, token?: string | undefined) => Promise<T>;
        find: (filter?: Filter<T> | undefined, token?: string | undefined, inclusionConfig?: RestRelationConfig | undefined) => Promise<T[]>;
        count: (where?: Where<T> | undefined, token?: string | undefined) => Promise<import("@loopback/repository").Count>;
        updateById: (id: string, data: DataObject<T>, token?: string | undefined) => Promise<void>;
        deleteById: (id: string, token?: string | undefined) => Promise<void>;
        update: (data: DataObject<T>, where?: Where<T> | undefined, token?: string | undefined) => Promise<import("@loopback/repository").Count>;
        replaceById: (id: string, data: DataObject<T>, token?: string | undefined) => Promise<void>;
        delete: (where?: Where<T> | undefined, token?: string | undefined) => Promise<void>;
    }>;
    create(service: CrudRestService<T>, data: DataObject<T>, token?: string): Promise<T>;
    findById(service: CrudRestService<T>, model: ModelConstructor<T>, config: RestRelationConfig[], id: string, filter?: FilterExcludingWhere<T>, token?: string): Promise<T>;
    find(service: CrudRestService<T>, model: ModelConstructor<T>, config: RestRelationConfig[], filter?: Filter<T>, token?: string, inclusionConfig?: RestRelationConfig): Promise<T[]>;
    count(service: CrudRestService<T>, where?: Where<T>, token?: string): Promise<import("@loopback/repository").Count>;
    updateById(service: CrudRestService<T>, id: string, data: DataObject<T>, token?: string): Promise<void>;
    deleteById(service: CrudRestService<T>, id: string, token?: string): Promise<void>;
    delete(service: CrudRestService<T>, where?: Where<T>, token?: string): Promise<void>;
    update(service: CrudRestService<T>, data: DataObject<T>, where?: Where<T>, token?: string): Promise<import("@loopback/repository").Count>;
    replaceById(service: CrudRestService<T>, id: string, data: DataObject<T>, token?: string): Promise<void>;
    /**
     * It takes a filter and a list of relations, and returns a list of relations that are REST relations,
     * and a map of scopes for those relations
     * @param {RestRelationConfig[]} configs - RestRelationConfig[]
     * @param [filter] - The filter object that was passed to the find method.
     * @returns An object with two properties: restRelations and scopeMap.
     */
    private _relationsFromFilter;
    private _updateFilter;
    private _extraFilters;
    /**
     * It takes a list of relations, a list of results, and a token, and returns a list of results with the
     * relations resolved
     * @param {RestRelationConfig[]} relations - RestRelationConfig[]
     * @param scopeMap - Map<string, Filter<S>>
     * @param model - The model class that we are querying
     * @param {T[]} results - The results of the query.
     * @param {string} token - The access token of the current user.
     */
    private _resolveRelations;
    private _configsHaveRelations;
}
