"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TenantContextMiddlewareInterceptorProvider = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const keys_1 = require("../keys");
let TenantContextMiddlewareInterceptorProvider = class TenantContextMiddlewareInterceptorProvider {
    constructor(currentUser, coreConfig, tenantIdEncryptionProvider) {
        this.currentUser = currentUser;
        this.coreConfig = coreConfig;
        this.tenantIdEncryptionProvider = tenantIdEncryptionProvider;
    }
    value() {
        return this.intercept.bind(this);
    }
    /**
     * The intercept function checks for a request context, encrypts the tenant ID, and adds it to the
     * request headers if the current user has a tenant ID and a secret key is available.
     */
    async intercept(context, next) {
        var _a;
        let request, response;
        if (this.isRequestContext(context.parent)) {
            request = context.parent.request;
            response = context.parent.response;
        }
        if (request && response && ((_a = this.currentUser) === null || _a === void 0 ? void 0 : _a.tenantId)) {
            if (!this.coreConfig.tenantContextEncryptionKey) {
                request.headers['tenant-id'] = this.currentUser.tenantId;
            }
            else {
                const encryptedTenantId = await this.tenantIdEncryptionProvider(this.coreConfig.tenantContextEncryptionKey, this.currentUser.tenantId);
                request.headers['tenant-id'] = encryptedTenantId;
            }
        }
        return next();
    }
    isRequestContext(context) {
        return !!(context.request &&
            context.response);
    }
};
exports.TenantContextMiddlewareInterceptorProvider = TenantContextMiddlewareInterceptorProvider;
exports.TenantContextMiddlewareInterceptorProvider = TenantContextMiddlewareInterceptorProvider = tslib_1.__decorate([
    (0, core_1.globalInterceptor)(),
    tslib_1.__param(0, (0, core_1.inject)(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.SFCoreBindings.config, { optional: true })),
    tslib_1.__param(2, (0, core_1.inject)(keys_1.SFCoreBindings.TENANTID_ENCRYPTION_PROVIDER)),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function])
], TenantContextMiddlewareInterceptorProvider);
//# sourceMappingURL=tenant-context.middleware.js.map