"use strict";
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
Object.defineProperty(exports, "__esModule", { value: true });
exports.addTenantId = void 0;
const tslib_1 = require("tslib");
const crypto_js_1 = tslib_1.__importDefault(require("crypto-js"));
/**
 * The function `addTenantId` extracts and decrypts a tenant ID from the request headers and adds it to
 * the response object.
 * @param {IncomingMessage} req - The `req` parameter is of type `IncomingMessage`, which represents an
 * incoming HTTP request.
 * @param res - The `res` parameter is used to send the response back to the client after processing the
 * request.
 * @param {AnyObject} reqResponse -  In the provided function, the 'tenant-id' property of reqResponse is being set based on the
 * 'tenant-id' header value from the incoming request.
 * @param {string} [secretKey] - The `secretKey` parameter in the `addTenantId` function is an optional
 * parameter of type `string`. It is used for decrypting the `tenant-id` value if provided. If the
 * `secretKey` is not provided, the `tenant-id` value is directly assigned to `req
 */
function addTenantId(req, res, reqResponse, secretKey) {
    if (!secretKey) {
        reqResponse['tenant-id'] = req.headers['tenant-id'];
    }
    else {
        const encryptedTenantId = req.headers['tenant-id'];
        const decryptedTenantId = crypto_js_1.default.AES.decrypt(encryptedTenantId, secretKey).toString(crypto_js_1.default.enc.Utf8);
        reqResponse['tenant-id'] = decryptedTenantId;
    }
}
exports.addTenantId = addTenantId;
//# sourceMappingURL=types.js.map